from __future__ import unicode_literals

from .models import AutoAdminSingleton


def auto_admin_account_password_change(sender, instance, **kwargs):
    auto_admin_properties, created = AutoAdminSingleton.objects.get_or_create()
    if instance == auto_admin_properties.account and instance.password != auto_admin_properties.password_hash:
        # Only delete the auto admin properties when the password
        # has been changed
        auto_admin_properties.account = None
        auto_admin_properties.password = None
        auto_admin_properties.password_hash = None
        auto_admin_properties.save()



from __future__ import unicode_literals

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from solo.models import SingletonModel


class AutoAdminSingleton(SingletonModel):
    account = models.ForeignKey(
        settings.AUTH_USER_MODEL, blank=True, null=True,
        verbose_name=_('Account')
    )
    password = models.CharField(
        blank=True, max_length=128, null=True, verbose_name=_('Password')
    )
    password_hash = models.CharField(
        blank=True, max_length=128, null=True, verbose_name=_('Password hash')
    )

    class Meta:
        verbose_name = verbose_name_plural = _('Autoadmin properties')



from __future__ import unicode_literals

__author__ = 'Roberto Rosario'
__build__ = 0x010001
__copyright__ = 'Copyright 2014 Roberto Rosario'
__license__ = 'MIT'
__title__ = 'django-autoadmin'
__version__ = '1.0.1'

default_app_config = 'autoadmin.apps.AutoAdminAppConfig'



from __future__ import unicode_literals

from django.conf import settings

EMAIL = getattr(settings, 'AUTOADMIN_EMAIL', 'autoadmin@example.com')
PASSWORD = getattr(settings, 'AUTOADMIN_PASSWORD', None)
USERNAME = getattr(settings, 'AUTOADMIN_USERNAME', 'admin')



from __future__ import unicode_literals

from django import apps
from django.conf import settings
from django.db.models.signals import post_save
from django.utils.translation import ugettext_lazy as _

from .handlers import auto_admin_account_password_change


class AutoAdminAppConfig(apps.AppConfig):
    name = 'autoadmin'
    verbose_name = _('Autoadmin')

    def ready(self):
        post_save.connect(
            auto_admin_account_password_change,
            dispatch_uid='auto_admin_account_password_change',
            sender=settings.AUTH_USER_MODEL
        )



#!/usr/bin/env python

import os
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import autoadmin

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

with open('README.rst') as f:
    readme = f.read()
with open('HISTORY.rst') as f:
    history = f.read()
with open('LICENSE') as f:
    license = f.read()

setup(
    author='Roberto Rosario',
    author_email='roberto.rosario.gonzalez@gmail.com',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
    ],
    description='Automatic admin users for Django projects.',
    include_package_data=True,
    install_requires=['django-solo>=1.1.0'],
    license=license,
    long_description=readme + '\n\n' + history,
    name='django-autoadmin',
    package_data={'': ['LICENSE']},
    package_dir={'autoadmin': 'autoadmin'},
    packages=['autoadmin', 'autoadmin.templatetags', 'autoadmin.management', 'autoadmin.management.commands'],
    platforms=['any'],
    url='https://github.com/rosarior/django-autoadmin',
    version=autoadmin.__version__,
    zip_safe=False,
)



from __future__ import unicode_literals

import logging

from django.contrib.auth import get_user_model
from django.core import management
from django.core.management.base import BaseCommand, CommandError

from ...models import AutoAdminSingleton
from ...settings import EMAIL, PASSWORD, USERNAME

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = 'Used to create a superuser with a secure and automatic password.'

    def handle(self, *args, **options):
        UserModel = get_user_model()

        # Get an usable password before creating the superuser
        if PASSWORD:
            try:
                # Let's try to see if it is a callable
                password = PASSWORD()
            except TypeError:
                password = PASSWORD
        else:
            password = get_user_model().objects.make_random_password()

        try:
            UserModel.objects.get(**{UserModel.USERNAME_FIELD: USERNAME})
        except UserModel.DoesNotExist:
            logger.info(
                'Creating superuser -- login: %s, email: %s, password: %s',
                USERNAME, EMAIL, password
            )
            management.call_command(
                'createsuperuser',
                **{
                    UserModel.USERNAME_FIELD: USERNAME,
                    'email': EMAIL,
                    'interactive': False
                }
            )

            account = UserModel.objects.get(
                **{
                    UserModel.USERNAME_FIELD: USERNAME
                }
            )
            account.set_password(raw_password=password)
            account.save()
            # Store the auto admin password properties to display the
            # first login message
            auto_admin_properties, created = AutoAdminSingleton.objects.get_or_create()
            auto_admin_properties.account = account
            auto_admin_properties.password = password
            auto_admin_properties.password_hash = account.password
            auto_admin_properties.save()
        else:
            raise CommandError('Superuser %s already exists.' % USERNAME)
            logger.error(
                'Super admin user already exists. -- login: %s', USERNAME
            )
